@@ -9,19 +9,22 @@
 
 module CLI (runCLI) where
 
-import Ast (Program (Program))
+import AST (Program (Program))
 import Control.Exception (Exception (displayException), SomeException, handle, throw, throwIO)
 import Control.Exception.Base
 import Control.Monad (when)
 import Data.Char (toLower, toUpper)
+import Data.Functor ((<&>))
 import Data.List (intercalate)
 import Data.Maybe (isJust, isNothing)
 import Data.Version (showVersion)
 import Dataize (DataizeContext (DataizeContext), dataize)
 import Deps (saveStep)
+import Encoding (Encoding (ASCII, UNICODE))
 import Functions (buildTerm)
 import qualified Functions
-import LaTeX (explainRules, programToLaTeX)
+import LaTeX (LatexContext (LatexContext), explainRules, programToLaTeX, rewrittensToLatex)
+import Lining (LineFormat (MULTILINE, SINGLELINE))
 import Logger
 import Misc (ensuredFile)
 import qualified Misc
@@ -29,8 +32,9 @@ import Must (Must (..))
 import Options.Applicative
 import Parser (parseProgramThrows)
 import Paths_phino (version)
-import Pretty (Encoding (UNICODE), PrintMode (SALTY, SWEET), prettyBytes, prettyProgram')
-import Rewriter (RewriteContext (RewriteContext), rewrite')
+import qualified Printer as P
+import Rewriter (RewriteContext (RewriteContext), Rewritten (..), rewrite')
+import Sugar
 import System.Exit (ExitCode (..), exitFailure)
 import System.IO (getContents')
 import Text.Printf (printf)
@@ -65,6 +69,8 @@ instance Show IOFormat where
 data OptsDataize = OptsDataize
   { logLevel :: LogLevel,
     inputFormat :: IOFormat,
+    sugarType :: SugarType,
+    flat :: LineFormat,
     maxDepth :: Integer,
     maxCycles :: Integer,
     depthSensitive :: Bool,
@@ -85,7 +91,8 @@ data OptsRewrite = OptsRewrite
     rules :: [FilePath],
     inputFormat :: IOFormat,
     outputFormat :: IOFormat,
-    printMode :: PrintMode,
+    sugarType :: SugarType,
+    flat :: LineFormat,
     normalize :: Bool,
     shuffle :: Bool,
     omitListing :: Bool,
@@ -95,6 +102,7 @@ data OptsRewrite = OptsRewrite
     maxDepth :: Integer,
     maxCycles :: Integer,
     inPlace :: Bool,
+    sequence :: Bool,
     targetFile :: Maybe FilePath,
     stepsDir :: Maybe FilePath,
     inputFile :: Maybe FilePath
@@ -159,6 +167,12 @@ optStepsDir = optional (strOption (long "steps-dir" <> metavar "FILE" <> help "D
 optShuffle :: Parser Bool
 optShuffle = switch (long "shuffle" <> help "Shuffle rules before applying")
 
+optSugar :: Parser SugarType
+optSugar = flag SALTY SWEET (long "sweet" <> help "Print result and intermediate (see --steps flag) 𝜑-programs using syntax sugar")
+
+optLineFormat :: Parser LineFormat
+optLineFormat = flag MULTILINE SINGLELINE (long "flat" <> help "Print result and intermediate (see --steps flag) 𝜑-programs in one line")
+
 explainParser :: Parser Command
 explainParser =
   CmdExplain
@@ -176,6 +190,8 @@ dataizeParser =
     <$> ( OptsDataize
             <$> optLogLevel
             <*> optInputFormat
+            <*> optSugar
+            <*> optLineFormat
             <*> optMaxDepth
             <*> optMaxCycles
             <*> optDepthSensitive
@@ -191,7 +207,8 @@ rewriteParser =
             <*> optRule
             <*> optInputFormat
             <*> option (parseIOFormat "output") (long "output" <> metavar "FORMAT" <> help "Program output format (phi, xmir)" <> value PHI <> showDefault)
-            <*> flag SALTY SWEET (long "sweet" <> help "Print 𝜑-program using syntax sugar")
+            <*> optSugar
+            <*> optLineFormat
             <*> optNormalize
             <*> optShuffle
             <*> switch (long "omit-listing" <> help "Omit full program listing in XMIR output")
@@ -208,6 +225,7 @@ rewriteParser =
             <*> optMaxDepth
             <*> optMaxCycles
             <*> switch (long "in-place" <> help "Edit file in-place instead of printing to output")
+            <*> switch (long "sequence" <> help "Result output contains all intermediate 𝜑-programs concatenated with EOL")
             <*> optTarget
             <*> optStepsDir
             <*> argInputFile
@@ -216,8 +234,8 @@ rewriteParser =
 commandParser :: Parser Command
 commandParser =
   hsubparser
-    ( command "rewrite" (info rewriteParser (progDesc "Rewrite the program"))
-        <> command "dataize" (info dataizeParser (progDesc "Dataize the program"))
+    ( command "rewrite" (info rewriteParser (progDesc "Rewrite the 𝜑-program"))
+        <> command "dataize" (info dataizeParser (progDesc "Dataize the 𝜑-program"))
         <> command "explain" (info explainParser (progDesc "Explain rules in LaTeX format"))
     )
 
@@ -254,15 +272,15 @@ runCLI args = handle handler $ do
       let xmirCtx = Just (XmirContext omitListing omitComments input)
       rules' <- getRules normalize shuffle rules
       program <- parseProgram input inputFormat
-      rewritten <- rewrite' program rules' (context program xmirCtx)
+      rewrittens <- rewrite' program rules' (context program xmirCtx)
       logDebug (printf "Printing rewritten 𝜑-program as %s" (show outputFormat))
-      prog <- printProgram outputFormat printMode xmirCtx rewritten
-      output targetFile prog
+      progs <- printRewrittens xmirCtx rewrittens
+      output targetFile progs
       where
         validateOpts :: IO ()
         validateOpts = do
           when
-            (printMode == SWEET && outputFormat == XMIR)
+            (sugarType == SWEET && outputFormat == XMIR)
             (throwIO (InvalidRewriteArguments "The --sweet and --output=xmir can't stay together"))
           when
             (inPlace && isNothing inputFile)
@@ -293,15 +311,20 @@ runCLI args = handle handler $ do
             maxDepth
             maxCycles
             depthSensitive
+            sequence
             buildTerm
             must
-            (saveStep stepsDir (ioToExtension outputFormat) (printProgram outputFormat printMode ctx))
+            (saveStep stepsDir (ioToExtension outputFormat) (printProgram outputFormat (sugarType, flat) ctx))
+        printRewrittens :: Maybe XmirContext -> [Rewritten] -> IO String
+        printRewrittens ctx rewrittens
+          | outputFormat == LATEX = pure (rewrittensToLatex rewrittens (LatexContext sugarType flat))
+          | otherwise = mapM (printProgram outputFormat (sugarType, flat) ctx . program) rewrittens <&> intercalate "\n"
     CmdDataize opts@OptsDataize {..} -> do
       validateOpts
       input <- readInput inputFile
       prog <- parseProgram input inputFormat
       dataized <- dataize prog (context prog)
-      maybe (throwIO CouldNotDataize) (putStrLn . prettyBytes) dataized
+      maybe (throwIO CouldNotDataize) (putStrLn . P.printBytes) dataized
       where
         validateOpts :: IO ()
         validateOpts = do
@@ -315,7 +338,7 @@ runCLI args = handle handler $ do
             maxCycles
             depthSensitive
             buildTerm
-            (saveStep stepsDir (ioToExtension PHI) (printProgram PHI SWEET Nothing))
+            (saveStep stepsDir (ioToExtension PHI) (printProgram PHI (SWEET, MULTILINE) Nothing))
     CmdExplain opts@OptsExplain {..} -> do
       validateOpts
       rules' <- getRules normalize shuffle rules
@@ -364,13 +387,11 @@ runCLI args = handle handler $ do
     parseProgram xmir XMIR = do
       doc <- parseXMIRThrows xmir
       xmirToPhi doc
-    printProgram :: IOFormat -> PrintMode -> Maybe XmirContext -> Program -> IO String
-    printProgram PHI mode _ prog = pure (prettyProgram' prog mode UNICODE)
-    printProgram XMIR mode Nothing prog = printProgram XMIR mode (Just defaultXmirContext) prog
-    printProgram XMIR _ (Just ctx) prog = do
-      xmir <- programToXMIR prog ctx
-      pure (printXMIR xmir)
-    printProgram LATEX mode _ prog = pure (programToLaTeX prog mode)
+    printProgram :: IOFormat -> (SugarType, LineFormat) -> Maybe XmirContext -> Program -> IO String
+    printProgram PHI (sugar, line) _ prog = pure (P.printProgram' prog (sugar, UNICODE, line))
+    printProgram XMIR cfg Nothing prog = printProgram XMIR cfg (Just defaultXmirContext) prog
+    printProgram XMIR _ (Just ctx) prog = programToXMIR prog ctx <&> printXMIR
+    printProgram LATEX (sugar, line) _ prog = pure (programToLaTeX prog (LatexContext sugar line))
     getRules :: Bool -> Bool -> [FilePath] -> IO [Y.Rule]
     getRules normalize shuffle rules = do
       ordered <-
