@@ -9,7 +9,7 @@
 -- Functions module because Rewriter does not depend on Functions anymore.
 module Deps where
 
-import Ast
+import AST
 import Logger (logDebug)
 import Matcher
 import System.Directory (createDirectoryIfMissing)
@@ -31,10 +31,10 @@ type SaveStepFunc = Program -> Integer -> IO ()
 
 saveStep :: Maybe FilePath -> String -> (Program -> IO String) -> SaveStepFunc
 saveStep Nothing _ _ _ _ = pure ()
-saveStep (Just dir) ext print' prog step = do
+saveStep (Just dir) ext print prog step = do
   createDirectoryIfMissing True dir
   let path = dir </> printf "%05d.%s" step ext
-  content <- print' prog
+  content <- print prog
   writeFile path content
   logDebug (printf "Saved step '%d' to '%s'" step path)
 
