@@ -18,7 +18,7 @@ module XMIR
   )
 where
 
-import Ast
+import AST
 import Control.Exception (Exception (displayException), SomeException, throwIO)
 import Control.Exception.Base (Exception)
 import qualified Data.Bifunctor
@@ -36,10 +36,9 @@ import Data.Time
 import Data.Time.Clock.POSIX (utcTimeToPOSIXSeconds)
 import Data.Time.Format (defaultTimeLocale, formatTime)
 import Data.Version (showVersion)
-import Debug.Trace
 import Misc
 import Paths_phino (version)
-import Pretty (PrintMode (SWEET), prettyAttribute, prettyBinding, prettyBytes, prettyExpression, prettyProgram)
+import Printer
 import Text.Printf (printf)
 import qualified Text.Read as TR
 import Text.XML
@@ -63,9 +62,9 @@ data XMIRException
   deriving (Exception)
 
 instance Show XMIRException where
-  show UnsupportedProgram {..} = printf "XMIR does not support such program:\n%s" (prettyProgram prog)
-  show UnsupportedExpression {..} = printf "XMIR does not support such expression:\n%s" (prettyExpression expr)
-  show UnsupportedBinding {..} = printf "XMIR does not support such bindings: %s" (prettyBinding binding)
+  show UnsupportedProgram {..} = printf "XMIR does not support such program:\n%s" (printProgram prog)
+  show UnsupportedExpression {..} = printf "XMIR does not support such expression:\n%s" (printExpression expr)
+  show UnsupportedBinding {..} = printf "XMIR does not support such bindings: %s" (printBinding binding)
   show CouldNotParseXMIR {..} = printf "Couldn't parse given XMIR, cause: %s" message
   show InvalidXMIRFormat {..} =
     printf
@@ -89,14 +88,14 @@ object :: [(String, String)] -> [Node] -> Node
 object attrs children = NodeElement (element "o" attrs children)
 
 expression :: Expression -> XmirContext -> IO (String, [Node])
-expression ExThis _ = pure (prettyExpression ExThis, [])
-expression ExGlobal _ = pure (prettyExpression ExGlobal, [])
+expression ExThis _ = pure (printExpression ExThis, [])
+expression ExGlobal _ = pure (printExpression ExGlobal, [])
 expression (ExFormation bds) ctx = do
   nested <- nestedBindings bds ctx
   pure ("", nested)
 expression (ExDispatch expr attr) ctx = do
   (base, children) <- expression expr ctx
-  let attr' = prettyAttribute attr
+  let attr' = printAttribute attr
   if null base
     then pure ('.' : attr', [object [] children])
     else
@@ -106,8 +105,8 @@ expression (ExDispatch expr attr) ctx = do
 expression (DataNumber bytes) XmirContext {..} =
   let bts =
         object
-          [("as", prettyAttribute (AtAlpha 0)), ("base", "Φ.org.eolang.bytes")]
-          [object [] [NodeContent (T.pack (prettyBytes bytes))]]
+          [("as", printAttribute (AtAlpha 0)), ("base", "Φ.org.eolang.bytes")]
+          [object [] [NodeContent (T.pack (printBytes bytes))]]
    in pure
         ( "Φ.org.eolang.number",
           if omitComments
@@ -120,8 +119,8 @@ expression (DataNumber bytes) XmirContext {..} =
 expression (DataString bytes) XmirContext {..} =
   let bts =
         object
-          [("as", prettyAttribute (AtAlpha 0)), ("base", "Φ.org.eolang.bytes")]
-          [object [] [NodeContent (T.pack (prettyBytes bytes))]]
+          [("as", printAttribute (AtAlpha 0)), ("base", "Φ.org.eolang.bytes")]
+          [object [] [NodeContent (T.pack (printBytes bytes))]]
    in pure
         ( "Φ.org.eolang.string",
           if omitComments
@@ -134,7 +133,7 @@ expression (DataString bytes) XmirContext {..} =
 expression (ExApplication expr (BiTau attr texpr)) ctx = do
   (base, children) <- expression expr ctx
   (base', children') <- expression texpr ctx
-  let as = prettyAttribute attr
+  let as = printAttribute attr
       attrs =
         if null base'
           then [("as", as)]
@@ -154,7 +153,7 @@ formationBinding (BiTau AtPhi expr) ctx = do
   (base, children) <- expression expr ctx
   pure (Just (object [("name", show AtPhi), ("base", base)] children))
 formationBinding (BiTau AtRho _) _ = pure Nothing
-formationBinding (BiDelta bytes) _ = pure (Just (NodeContent (T.pack (prettyBytes bytes))))
+formationBinding (BiDelta bytes) _ = pure (Just (NodeContent (T.pack (printBytes bytes))))
 formationBinding (BiLambda func) _ = pure (Just (object [("name", show AtLambda)] []))
 formationBinding (BiVoid AtRho) _ = pure Nothing
 formationBinding (BiVoid AtPhi) _ = pure (Just (object [("name", show AtPhi), ("base", "∅")] []))
@@ -216,7 +215,7 @@ programToXMIR prog@(Program expr@(ExFormation [BiTau (AtLabel _) arg, BiVoid AtR
       pure (label : pckg, expr')
     getPackage (ExFormation [BiTau attr expr, BiLambda "Package", BiVoid AtRho]) = pure ([], ExFormation [BiTau attr expr, BiVoid AtRho])
     getPackage (ExFormation [bd, BiVoid AtRho]) = pure ([], ExFormation [bd, BiVoid AtRho])
-    getPackage expr = throwIO (userError (printf "Can't extract package from given expression:\n %s" (prettyExpression expr)))
+    getPackage expr = throwIO (userError (printf "Can't extract package from given expression:\n %s" (printExpression expr)))
     -- Convert root Expression to Node
     rootExpression :: Expression -> XmirContext -> IO Node
     rootExpression (ExFormation [bd, BiVoid AtRho]) ctx = do
