@@ -238,22 +238,18 @@ spec = do
       withStdin "Q -> [[ x -> QQ.z(y -> 5), q -> T, w -> $, ^ -> Q, @ -> 1, y -> \"H$@^M\"]]" $
         testCLISucceeded
           ["rewrite", "--output=latex", "--sweet"]
-          [ "\\documentclass{article}",
-            "\\usepackage{eolang}",
-            "\\begin{document}",
-            "\\begin{phiquation}",
+          [ "\\begin{phiquation}",
             "{[[",
             "  x -> QQ.z(",
             "    y -> 5",
             "  ),",
             "  q -> T,",
-            "  w -> \\char36{},",
-            "  \\char94{} -> Q,",
-            "  \\char64{} -> 1,",
-            "  y -> \"H\\char36{}\\char64{}\\char94{}M\"",
+            "  w -> $,",
+            "  ^ -> Q,",
+            "  @ -> 1,",
+            "  y -> \"H$@^M\"",
             "]]}",
-            "\\end{phiquation}",
-            "\\end{document}"
+            "\\end{phiquation}"
           ]
 
     it "rewrites with XMIR as input" $
@@ -281,6 +277,47 @@ spec = do
           ["rewrite", "--rule=test-resources/cli/simple.yaml", "--must=1", "--sweet"]
           ["x ↦ \"bar\""]
 
+    it "prints many programs with --sequence" $
+      withStdin "{[[ x -> \"foo\" ]]}" $
+        testCLISucceeded
+          [ "rewrite",
+            "--rule=test-resources/cli/first.yaml",
+            "--rule=test-resources/cli/second.yaml",
+            "--max-depth=1",
+            "--max-cycles=2",
+            "--sequence",
+            "--sweet",
+            "--flat"
+          ]
+          [ unlines
+              [ "{⟦ x ↦ \"foo\" ⟧}",
+                "{Φ.x( y ↦ \"foo\" )}",
+                "{⟦ x ↦ \"foo\" ⟧}"
+              ]
+          ]
+
+    it "prints only one latex preamble with --sequence" $
+      withStdin "{[[ x -> \"foo\" ]]}" $
+        testCLISucceeded
+          [ "rewrite",
+            "--rule=test-resources/cli/first.yaml",
+            "--rule=test-resources/cli/second.yaml",
+            "--max-depth=1",
+            "--max-cycles=2",
+            "--sequence",
+            "--sweet",
+            "--flat",
+            "--output=latex"
+          ]
+          [ unlines
+              [ "\\begin{phiquation}",
+                "{[[ x -> \"foo\" ]]} \\leadsto_{\\nameref{r:first}}",
+                "\\leadsto {Q.x( y -> \"foo\" )} \\leadsto_{\\nameref{r:second}}",
+                "\\leadsto {[[ x -> \"foo\" ]]}",
+                "\\end{phiquation}"
+              ]
+          ]
+
     describe "must range tests" $ do
       describe "fails" $ do
         it "when cycles exceed range ..1" $
@@ -368,6 +405,12 @@ spec = do
               ]
           ]
 
+    it "prints in line with --flat" $
+      withStdin "Q -> [[ x -> 5, y -> \"hey\", z -> [[ w -> [[ ]] ]] ]]" $
+        testCLISucceeded
+          ["rewrite", "--sweet", "--flat"]
+          ["{⟦ x ↦ 5, y ↦ \"hey\", z ↦ ⟦ w ↦ ⟦⟧ ⟧ ⟧}"]
+
   describe "dataize" $ do
     it "dataizes simple program" $
       withStdin "Q -> [[ D> 01- ]]" $
