@@ -1,6 +1,7 @@
 {-# LANGUAGE DeriveAnyClass #-}
 {-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE LambdaCase #-}
+{-# LANGUAGE RecordWildCards #-}
 {-# OPTIONS_GHC -Wno-orphans #-}
 
 -- SPDX-FileCopyrightText: Copyright (c) 2025 Objectionary.com
@@ -18,8 +19,8 @@ import GHC.Generics
 import Misc (allPathsIn, ensuredFile)
 import Must (Must (..))
 import Parser (parseProgramThrows)
-import Pretty (Encoding (UNICODE), PrintMode (SWEET), prettyProgram')
-import Rewriter (RewriteContext (RewriteContext), rewrite')
+import Printer (printProgram)
+import Rewriter (RewriteContext (RewriteContext), Rewritten (..), rewrite')
 import System.FilePath (makeRelative, replaceExtension, (</>))
 import Test.Hspec (Spec, describe, expectationFailure, it, pending, runIO)
 import Yaml (normalizationRules)
@@ -81,7 +82,7 @@ spec =
           case skip pack of
             Just True -> pending
             _ -> do
-              program <- parseProgramThrows (input pack)
+              prog <- parseProgramThrows (input pack)
               rules' <- case rules pack of
                 Just _rules -> case custom _rules of
                   Just custom' -> pure custom'
@@ -98,25 +99,26 @@ spec =
                   if normalize'
                     then pure normalizationRules
                     else pure []
-              rewritten <-
+              [Rewritten {..}] <-
                 rewrite'
-                  program
+                  prog
                   rules'
                   ( RewriteContext
-                      program
+                      prog
                       repeat'
                       repeat'
                       False
+                      False
                       buildTerm
                       must'
                       dontSaveStep
                   )
               result' <- parseProgramThrows (output pack)
-              unless (rewritten == result') $
+              unless (program == result') $
                 expectationFailure
                   ( "Wrong rewritten program. Expected:\n"
-                      ++ prettyProgram' result' SWEET UNICODE
+                      ++ printProgram result'
                       ++ "\nGot:\n"
-                      ++ prettyProgram' rewritten SWEET UNICODE
+                      ++ printProgram program
                   )
       )
